import { typescript } from 'projen';
/**
 * @stability stable
 */
export interface TurborepoPipelineConfig {
    /**
     * The list of tasks that this task depends on.
     *
     * Prefixing a task in `dependsOn` with a `^` tells `turbo` that this pipeline task depends on the
     * package's topological dependencies completing the task with the `^` prefix first (e.g. "a
     * package's `build` tasks should only run once all of its `dependencies` and `devDependencies`
     * have completed their own `build` commands").
     *
     * Items in `dependsOn` without `^` prefix, express the relationships between tasks at the package
     * level (e.g. "a package's `test` and `lint` commands depend on `build` being completed first").
     *
     * @stability stable
     */
    readonly dependsOn?: string[];
    /**
     * Defaults to `["dist/**", "build/**"]`. The set of glob patterns of a task's cacheable filesystem outputs.
     *
     * Note: `turbo` automatically logs `stderr`/`stdout` to `.turbo/run-<task>.log`. This file is
     * _always_ treated as a cacheable artifact and never needs to be specified.
     *
     * Passing an empty array can be used to tell `turbo` that a task is a side-effect and thus
     * doesn't emit any filesystem artifacts (e.g. like a linter), but you still want to cache its
     * logs (and treat them like an artifact).
     *
     * @stability stable
     */
    readonly outputs?: string[];
    /**
     * Whether or not to cache the task `outputs`.
     *
     * Setting `cache` to false is useful for daemon or long-running "watch" or development mode tasks
     * that you don't want to cache.
     *
     * @default true
     * @stability stable
     */
    readonly cache?: boolean;
}
/**
 * @stability stable
 */
export interface TurborepoConfig {
    /**
     * A list of globs for implicit global hash dependencies.
     *
     * The contents of these files will be
     * included in the global hashing algorithm. This is useful for busting the cache based on `.env`
     * files (not in Git) or any root level file that impacts package tasks (but are not represented
     * in the traditional dependency graph (e.g. a root `tsconfig.json`, `jest.config.js`, `.eslintrc`
     * , etc.)).
     *
     * @see https://turborepo.org/docs/reference/configuration#globaldependencies
     * @stability stable
     */
    readonly globalDependencies?: string[];
    /**
     * An object representing the task dependency graph of your project.
     *
     * `turbo` interprets these
     * conventions to properly schedule, execute, and cache the outputs of tasks in your project
     *
     * Each key in the `pipeline` object is the name of a task that can be executed by `turbo run`. If
     * `turbo` finds a workspace package with a `package.json` `scripts` object with a matching key,
     * it will apply the pipeline task configuration to that NPM script during execution. This allows
     * you to use `pipeline` to set conventions across your entire Turborepo.
     *
     * @see https://turborepo.org/docs/reference/configuration#pipeline
     * @stability stable
     */
    readonly pipeline?: Record<string, TurborepoPipelineConfig>;
}
/**
 * @stability stable
 */
export interface TurborepoProjectOptions extends typescript.TypeScriptProjectOptions {
    /**
     * Turborepo config options.
     *
     * @default {}
     * @stability stable
     */
    readonly turbo?: TurborepoConfig;
    /**
     * (experimental) Add TypeScript path maps in the root project for sub-projects.
     *
     * @default false
     * @experimental
     */
    readonly pathMapping?: boolean;
    /**
     * (experimental) Add jest config for `moduleNameMapper`.
     *
     * @default false
     * @see https://kulshekhar.github.io/ts-jest/docs/getting-started/paths-mapping/
     * @experimental
     */
    readonly jestModuleNameMapper?: boolean;
    /**
     * (experimental) Adds TypeScript project references for each sub-project that depends on other sub-project.
     *
     * @default false
     * @see https://www.typescriptlang.org/docs/handbook/project-references.html
     * @experimental
     */
    readonly projectReferences?: boolean;
    /**
     * (experimental) **GitHub Build Workflows**.
     *
     * Adds parallel GitHub Build workflows for each sub-project.
     *
     * @default false
     * @experimental
     */
    readonly parallelWorkflows?: boolean;
    /**
     * (experimental) VS Code Multi-root Workspaces.
     *
     * Adds support for VS Code multi-root workspaces.
     *
     * @default false
     * @see https://code.visualstudio.com/docs/editor/multi-root-workspaces
     * @experimental
     */
    readonly vscodeMultiRootWorkspaces?: boolean;
}
/**
 * @stability stable
 */
export declare class TurborepoProject extends typescript.TypeScriptProject {
    private readonly pathMapping;
    private readonly projectReferences;
    private readonly jestModuleNameMapper;
    private readonly parallelWorkflows;
    private readonly vscodeMultiRootWorkspaces;
    /**
     * @stability stable
     */
    constructor(options: TurborepoProjectOptions);
    private get subProjects();
    private turboRunTask;
    /**
     * Called before all components are synthesized.
     *
     * @stability stable
     */
    preSynthesize(): void;
}
